@@ -97,7 +97,7 @@ def s3_fixture_factory(
     @pytest.fixture
     def s3_fixture() -> Generator[S3Fixture, None, None]:
         """Pytest fixture for tests depending on the ObjectStorageS3 DAO."""
-        with LocalStackContainer(image="localstack/localstack:0.11.4").with_services(
+        with LocalStackContainer(image="localstack/localstack:0.14.2").with_services(
             "s3"
         ) as localstack:
             config = config_from_localstack_container(localstack)
@@ -219,7 +219,7 @@ def get_initialized_upload(s3_fixture: S3Fixture):
 
     bucket_id = s3_fixture.existing_buckets[0]
     object_id = s3_fixture.non_existing_objects[0].object_id
-    upload_id = s3_fixture.storage.init_mulitpart_upload(
+    upload_id = s3_fixture.storage.init_multipart_upload(
         bucket_id=bucket_id, object_id=object_id
     )
 
